struct RiverPixels {}Expand description
The rivers.png/bmp has an indexed palette where the colors don’t matter, only the index values
used in the pixels matter. Pixels that are not among the values defined here are ignored when
the game processes the rivers.png/bmp.
Implementations
Sourceimpl RiverPixels
impl RiverPixels
Sourceconst NORMAL: RangeInclusive<u8>
const NORMAL: RangeInclusive<u8>
Normal rivers of various widths (usually blue through greenish).
They are still all one pixel wide in the rivers.png/bmp; this just controls how they are painted on the map.
River pixels must be adjacent to each other horizontally or vertically; together they form river segments.
River widths go up to 15 even though the vanilla maps only use up to 11 (confirmed for CK3 and Hoi4).
const FIRST_NORMAL: u8 = 3
const LAST_NORMAL: u8 = 15
Sourceconst SPECIAL: RangeToInclusive<u8>
const SPECIAL: RangeToInclusive<u8>
“specials” are the starting and ending pixels of river segments
const LAST_SPECIAL: u8 = 2
Sourceconst SPLIT: u8 = 2
const SPLIT: u8 = 2
A pixel that is used where a river splits off from another (usually yellow)
Sourceconst FIRST_IGNORE: u8 = 16
const FIRST_IGNORE: u8 = 16
Noncoding pixels